@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006 Christoph Berg <cb@df7cb.de>
+# Copyright (C) 2004-2014 Christoph Berg <cb@df7cb.de>
 #
 # This file originated from the mapmarkers distribution:
 #
@@ -111,15 +111,19 @@ sub new {
 	}
 
 	# handle projection system
-	if ($config->{projection} eq 'mercator') {
+	if ($config->{projection} eq 'square') {
+		# degree per pixel RESolution
+		$config->{xres} = ($config->{east} - $config->{west}) / $config->{w};
+		$config->{yres} = ($config->{north} - $config->{south}) / $config->{h};
+	} elsif ($config->{projection} eq 'mercator') {
 		# degree per pixel RESolution
 		$config->{xres} = ($config->{east} - $config->{west}) / $config->{w};
 		$config->{yres} = ($config->{north} - $config->{south}) / $config->{h};
 	} elsif ($config->{projection} eq 'sinusoidal') {
 		die "center_lon must be defined for sinusoidal maps" unless defined $config->{center_lon};
 		# These 2 are not in pixels, but in absolute coordinates. To get pixels, they should be multiplied by $xres.
-		$config->{Xleft} = ($config->{west} - $config->{center_lon}) * cos($config->{north} * $degtorad);
-		$config->{Xright}  = ($config->{east} - $config->{center_lon}) * cos($config->{south} * $degtorad);
+		$config->{Xleft} = ($config->{west} - $config->{center_lon});
+		$config->{Xright}  = ($config->{east} - $config->{center_lon});
 
 		# number of unitary graduation / pixel for x (RESolution)
 		$config->{xres} = ($config->{Xright} - $config->{Xleft}) / $config->{w};
@@ -141,16 +145,24 @@ sub coord2pixel {
 	my($x, $y, $X0);
 	my $vis = 1;
 
-	if ($config->{projection} eq 'mercator') {
+	if ($config->{projection} eq 'square') {
 		# pixel values, sprintf rounds to nearest
 		$x = sprintf("%d", ($lon - $config->{west}) / $config->{xres});
 		$y = sprintf("%d", ($config->{north} - $lat) / $config->{yres});
 		$vis = 0 if ($lon > $config->{east} or $lon < $config->{west} or $lat > $config->{north} or $lat < $config->{south});
+	} elsif ($config->{projection} eq 'mercator') {
+		$x = sprintf("%d", ($lon - $config->{west}) / $config->{xres});
+		$lat = 89.9 if ($lat == 90);
+		$lat = -89.9 if ($lat == -90);
+		my $yrad = $lat * $degtorad;
+		my $yscaled = 0.5 * log((1 + sin $yrad) / (1 - sin $yrad));
+		$y = sprintf("%d", $config->{h} / 2 - ($yscaled * $radtodeg / $config->{xres}));
+		$vis = 0 if ($lon > $config->{east} or $lon < $config->{west} or $lat > $config->{north} or $lat < $config->{south});
 	} elsif ($config->{projection} eq 'sinusoidal') {
 		# absolute X
 		$X0 = ($lon - $config->{center_lon}) * cos($lat * $degtorad);
 		# pixel values
-		$x = sprintf("%d", ($X0 - $config->{Xleft}) / $config->{xres});
+		$x = sprintf("%d", ($X0 - $config->{west}) / $config->{xres});
 		$y = sprintf("%d", ($config->{north} - $lat) / $config->{yres});
 		$vis = 0 if ($X0 < $config->{Xleft} or $X0 > $config->{Xright} or $lat > $config->{north} or $lat < $config->{south});
 	}
